@@ -1,21 +1,9 @@
 /*
- * Copyright (C) 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
- * Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef BOMBER_WIDGET_H
 #define BOMBER_WIDGET_H
@@ -24,7 +12,7 @@
 #include <QGraphicsView>
 #include <QMouseEvent>
 
-// KDE
+// KDEGames
 #include <KgSound>
 
 // Bomber
@@ -51,7 +39,7 @@ public:
                        GameOver };
 
     explicit BomberGameWidget(KgThemeProvider * provider, QWidget * parent = nullptr);
-    ~BomberGameWidget();
+    ~BomberGameWidget() override;
 
     /**
      * Used to find out the current level
@@ -169,8 +157,8 @@ private Q_SLOTS:
     void onPlaneCrashed();
 
 private:
-    virtual void resizeEvent(QResizeEvent * event) Q_DECL_OVERRIDE;
-    virtual void mouseReleaseEvent(QMouseEvent * event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent * event) override;
+    void mouseReleaseEvent(QMouseEvent * event) override;
 
     /**
      * Create the overlay used to display info to the user. The info will
